@@ -439,12 +439,6 @@ void FCWT::cwt(float *pinput, int psize, complex<float>* poutput, Scales *scales
         Ihat = (fftwf_complex*)aligned_alloc(32, newsize*sizeof(fftwf_complex));
         O1 = (fftwf_complex*)aligned_alloc(32, newsize*sizeof(fftwf_complex));
     #endif
-
-    #ifdef AVX
-        std::cout << "AVX support detected" << std::endl;
-    #else
-        std::cout << "AVX support not detected" << std::endl;
-    #endif
     
     //Copy input to new input buffer
     memcpy(input,pinput,sizeof(float)*size);
